
# Slot: dims




URI: [nwb_schema_language:dims](https://w3id.org/p2p_ld/nwb-schema-language/dims)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Attribute](Attribute.md)
 * [Dataset](Dataset.md)
